SvgImportResult class final

Editable shapes and explicit losses from importing a supported SVG subset.

Constructors

SvgImportResult(Iterable<ShapeElement> elements, Iterable<String> warnings)

Properties

elements → List<ShapeElement>
The imported shapes, in document order.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
warnings → List<String>
What the import omitted or approximated, without duplicates, such as <text> is omitted.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited